@@ -1380,7 +1380,6 @@ namespace Drawing {
         }
         if (nTracks > 0) {
             float y = totalCovY + refSpace + (trackY*(float)nbams) + (gap * 0.5);
-//            float y = fb_height - totalTabixY - refSpace;
             float step = totalTabixY / (float) nTracks;
             path.reset();
             for (int i = 0; i < (int) nTracks; ++i) {
@@ -1503,7 +1502,7 @@ namespace Drawing {
         SkPath path;
         path.moveTo(padX, startY - y_negativeValueOffset);
         path.lineTo(padX + stepX - gap2, startY - y_negativeValueOffset);
-        canvas->drawPath(path, opts.theme.fcBigWig);
+        canvas->drawPath(path, faceColour);
 //        }
         int step = length / 100000;
         step = (step) ? step : 1;
@@ -1516,7 +1515,7 @@ namespace Drawing {
             v = trk.bigWig_intervals->value[i];
             x = padX + (((float)trk.bigWig_intervals->start[i] - (float)rgn.start) * xScaling);
             rect.setXYWH(x, startY - y_negativeValueOffset, std::fmax(1, xScaling), -v * availableSPace);
-            canvas->drawRect(rect, opts.theme.fcBigWig);
+            canvas->drawRect(rect, faceColour);
         }
         if (availableSPace > 2 * fonts.overlayHeight) {
             path.reset();
@@ -1544,64 +1543,58 @@ namespace Drawing {
                         float padX, float padY,
                         float y, float h, float stepX, float stepY, float gap, float gap2, float xScaling,
                         Themes::IniOptions &opts, SkCanvas *canvas, const Themes::Fonts &fonts,
-                        bool add_text, bool add_rect, bool v_line, bool shaded, float *labelsEnd, std::string &vartype,
+                        bool add_text, bool add_rect, bool shaded, float *labelsEnd, std::string &vartype,
                         float monitorScale, std::vector<TextItem> &text, bool addArc, bool isRoi, SkPaint &faceColour, float pointSlop, float strand) {
         float x = 0;
         float w;
 
         SkPaint arcColour;
-//        SkPaint faceColour, arcColour;
-        if (isRoi) {
-//            faceColour = opts.theme.fcRoi;
-        } else {
-            if (shaded) {
-                faceColour = opts.theme.fcCoverage;
-            } else {
-                faceColour = opts.theme.fcTrack;
-            }
-        }
+        SkPaint *faceColour2 = &faceColour;
 
         if (!vartype.empty()) {
             if (vartype == "DEL") {
                 if (addArc) {
                     arcColour = opts.theme.fcT;
                 } else {
-                    faceColour = opts.theme.fcT;
-                    faceColour.setAlpha(150);
+                    faceColour2 = &opts.theme.fcT;
+                    faceColour2->setAlpha(150);
                 }
 
             } else if (vartype == "DUP") {
                 if (addArc) {
                     arcColour = opts.theme.fcC;
                 } else {
-                    faceColour = opts.theme.fcC;
-                    faceColour.setAlpha(150);
+                    faceColour2 = &opts.theme.fcC;
+                    faceColour2->setAlpha(150);
                 }
             } else if (vartype == "INV") {
                 if (addArc) {
                     arcColour = opts.theme.fcA;
                 } else {
-                    faceColour = opts.theme.fcA;
-                    faceColour.setAlpha(150);
+                    faceColour2 = &opts.theme.fcA;
+                    faceColour2->setAlpha(150);
                 }
             } else {
                 addArc = false;
             }
         } else {
             addArc = false;
-        }
-
-        if (addArc) {
-            v_line = false;
+//            if (isRoi) {
+//            faceColour = opts.theme.fcRoi;
+//            } else {
+//                if (shaded) {
+//                    faceColour2 = //&opts.theme.fcCoverage;
+//                } else {
+//                    faceColour2 = &faceColour;
+//                faceColour = opts.theme.fcTrack;
+//                }
+//            }
         }
 
         x = (float) (start - rgn.start) * xScaling;
         w = std::fmax(monitorScale, (float) (stop - start) * xScaling);
         rect.setXYWH(x + padX, y + padY, w, h);
 
-//        if (rect.bottom() == 0) {
-//            return;
-//        }
         if (addArc) {
             arcColour.setStyle(SkPaint::kStroke_Style);
             arcColour.setStrokeWidth(monitorScale);
@@ -1643,22 +1636,24 @@ namespace Drawing {
 
         }
         else if (add_rect) {
-            if (strand == 1) {  // +
-                drawRightPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, opts.theme.lcBright, path, pointSlop);
-            } else if (strand == 2) {  // -
-                drawLeftPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, opts.theme.lcBright, path, pointSlop);
+            if (!shaded) {
+                if (strand == 1) {  // +
+                    drawRightPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, opts.theme.bgPaint, path, pointSlop);
+                    drawRightPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, opts.theme.lcJoins, path, pointSlop);
+                } else if (strand == 2) {  // -
+                    drawLeftPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, opts.theme.bgPaint, path, pointSlop);
+                    drawLeftPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, opts.theme.lcJoins, path, pointSlop);
+                }
+                canvas->drawRect(rect, *faceColour2);
+            } else {
+                if (strand == 1) {  // +
+                    drawRightPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, *faceColour2, path, pointSlop);
+                } else if (strand == 2) {  // -
+                    drawLeftPointedRectangleNoEdge(canvas, h, y + padY, x + padX, w, 0, *faceColour2, path, pointSlop);
+                }
             }
-            canvas->drawRect(rect, faceColour);
 
-            if (shaded) {
-                canvas->drawRect(rect, opts.theme.lcLightJoins);
-            }
         }
-//        if (v_line && x != 0) {
-//            path.moveTo(x + padX, y + padY);
-//            path.lineTo(x + padX, y + h + padY);
-//            canvas->drawPath(path, opts.theme.lcLightJoins);
-//        }
 
         if (!add_text) {
             return;
@@ -1684,11 +1679,12 @@ namespace Drawing {
         if (rightPoint > padX + stepX - gap2) {
             return;
         }
+
         *labelsEnd = leftPoint + estimatedTextWidth;
         rect.fLeft = leftPoint;
         text.emplace_back() = {SkTextBlob::MakeFromString(rid.c_str(), fonts.overlay),
                                rect.left(),
-                               rect.bottom() + fonts.overlayHeight};
+                               rect.bottom() + fonts.overlayHeight + monitorScale * 2};
 
     }
 
@@ -1698,51 +1694,30 @@ namespace Drawing {
                               float gap, Utils::TrackBlock &trk, bool any_text, const Utils::Region &rgn, SkRect &rect,
                               SkPath &path, SkPath &path2, float padX, float padY, float stepX, float stepY,
                               float y, float h, float h2, float h4, float gap2, float xScaling, int nLevels,
-                              float *labelsEnd, std::vector<TextItem> &text, bool vline, SkPaint &faceColour, float pointSlop, int strand) {
+                              float *labelsEnd, std::vector<TextItem> &text, SkPaint &faceColour, SkPaint &shadedFaceColour,
+                              float pointSlop, int strand, float monitorScale) {
 
         int target = (int) trk.s.size();
-        int stranded = trk.strand;
+//        int stranded = trk.strand;
         float screenLeftEdge = padX;
         float screenRightEdge = padX + (((float) rgn.end - (float) rgn.start) * xScaling);
         std::string empty_str;
         if (any_text) {
             drawTrackBlock(trk.start, trk.end, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap, gap2,
-                           xScaling, opts, canvas, fonts, true, false, false, false, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
+                           xScaling, opts, canvas, fonts, true, false, false, labelsEnd, empty_str, monitorScale, text, false, false, faceColour, pointSlop, strand);
         }
-        for (int i = 0; i < target; ++i) {
-            int s, e;
+        float x, yy, w;
+        int s, e;
+        for (int i = 0; i < target; ++i) {  // draw lines first and thickness == 1
             s = trk.s[i];
             e = trk.e[i];
             if (e < rgn.start) {
                 continue;
             }
-            bool add_line = (i == 0 && vline);  // vertical line at start of interval
-            assert (i < trk.drawThickness.size());
-            uint8_t thickness = trk.drawThickness[i];
-            if (thickness && s < rgn.end && e > rgn.start) {
-
-                if ((trk.coding_end != -1 && s >= trk.coding_end) ||
-                    (trk.coding_start != -1 && e <= trk.coding_start)) {
-                    thickness = 1;
-                }
-
-                if (s < trk.coding_end && e > trk.coding_end) { //overlaps, split into two blocks!
-                    drawTrackBlock(s, trk.coding_end, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap,
-                                   gap2, xScaling, opts, canvas, fonts, false, true, add_line, false, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
-                    drawTrackBlock(trk.coding_end, e, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap,
-                                   gap2, xScaling, opts, canvas, fonts, false, true, add_line, true, labelsEnd, empty_str, 0, text, false, false,  faceColour, pointSlop, strand);
-                }
-
-                else if (thickness == 1) {
-                    drawTrackBlock(s, e, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap, gap2, xScaling,
-                                   opts, canvas, fonts, false, true, add_line, true, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
-                } else {
-                    drawTrackBlock(s, e, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap, gap2, xScaling,
-                                   opts, canvas, fonts, false, true, add_line, false, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
-                }
-            }
-            float x, yy, w;
             yy = y + padY + (h / 2);
+            if (i == 0) {
+                continue;
+            }
             int lastEnd = (i > 0) ? trk.e[i - 1] : trk.start;
             if (lastEnd < s) {  // add arrows
                 x = std::max(((float) (lastEnd - rgn.start) * xScaling) + padX, (float) screenLeftEdge);
@@ -1751,28 +1726,63 @@ namespace Drawing {
                     path2.reset();
                     path2.moveTo(x, yy);
                     path2.lineTo(w, yy);
-                    canvas->drawPath(path2, opts.theme.lcLightJoins);
-                    if (stranded != 0 && w - x > 50) {
-                        while (x + 50 < w) {
-                            x += 50;
-                            path2.reset();
-                            if (stranded == 1) {
-                                path2.moveTo(x, yy);
-                                path2.lineTo(x - 6, yy + 6);
-                                path2.moveTo(x, yy);
-                                path2.lineTo(x - 6, yy - 6);
-                            } else {
-                                path2.moveTo(x, yy);
-                                path2.lineTo(x + 6, yy + 6);
-                                path2.moveTo(x, yy);
-                                path2.lineTo(x + 6, yy - 6);
-                            }
-                            canvas->drawPath(path2, opts.theme.lcJoins);
-                        }
-                    }
+                    canvas->drawPath(path2, opts.theme.lcGTFJoins);
+//                    if (stranded != 0 && w - x > 50) {
+//                        while (x + 50 < w) {
+//                            x += 50;
+//                            path2.reset();
+//                            if (stranded == 1) {
+//                                path2.moveTo(x, yy);
+//                                path2.lineTo(x - 6, yy + 6);
+//                                path2.moveTo(x, yy);
+//                                path2.lineTo(x - 6, yy - 6);
+//                            } else {
+//                                path2.moveTo(x, yy);
+//                                path2.lineTo(x + 6, yy + 6);
+//                                path2.moveTo(x, yy);
+//                                path2.lineTo(x + 6, yy - 6);
+//                            }
+//                            canvas->drawPath(path2, opts.theme.lcJoins);
+//                        }
+//                    }
                 }
             }
         }
+        for (int i = 0; i < target; ++i) {
+            s = trk.s[i];
+            e = trk.e[i];
+            if (e < rgn.start) {
+                continue;
+            }
+            assert (i < trk.drawThickness.size());
+            uint8_t thickness = trk.drawThickness[i];
+            if (thickness && s < rgn.end && e > rgn.start) {
+                int left_cds = std::min(trk.coding_start, trk.coding_end);
+                int right_cds = std::max(trk.coding_start, trk.coding_end);
+                if (s < right_cds && e > right_cds) { //overlaps, split into two blocks!
+                    drawTrackBlock(right_cds, e, trk.name, rgn, rect, path, padX, padY, y + (h * 0.25), h * 0.5, stepX, stepY, gap,
+                                   gap2, xScaling, opts, canvas, fonts, false, true, true, labelsEnd, empty_str, 0, text, false, false,  shadedFaceColour, pointSlop / 2, strand);
+                    drawTrackBlock(s, right_cds, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap,
+                                   gap2, xScaling, opts, canvas, fonts, false, true, false, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
+                    continue;
+                } else if (s < left_cds && e > left_cds) {
+                    drawTrackBlock(s, left_cds, trk.name, rgn, rect, path, padX, padY, y + (h * 0.25), h * 0.5, stepX, stepY, gap,
+                                   gap2, xScaling, opts, canvas, fonts, false, true, true, labelsEnd, empty_str, 0, text, false, false,  shadedFaceColour, pointSlop / 2, strand);
+                    drawTrackBlock(left_cds, e, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap,
+                                   gap2, xScaling, opts, canvas, fonts, false, true, false, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
+                    continue;
+                }
+
+                if (thickness == 1) {
+                    drawTrackBlock(s, e, trk.name, rgn, rect, path, padX, padY, y + (h * 0.25), h * 0.5, stepX, stepY, gap, gap2, xScaling,
+                                   opts, canvas, fonts, false, true, true, labelsEnd, empty_str, 0, text, false, false, shadedFaceColour, pointSlop / 2, strand);
+                } else if (thickness == 2) {
+                    drawTrackBlock(s, e, trk.name, rgn, rect, path, padX, padY, y, h, stepX, stepY, gap, gap2, xScaling,
+                                   opts, canvas, fonts, false, true, false, labelsEnd, empty_str, 0, text, false, false, faceColour, pointSlop, strand);
+                }
+            }
+
+        }
     }
 
     void drawTracks(Themes::IniOptions &opts, float fb_width, float fb_height,
@@ -1787,7 +1797,7 @@ namespace Drawing {
 
         float stepX = fb_width / (float) regions.size();
         float stepY = tabixY;
-        stepY -= sliderSpace - gap;  // todo this should not be needed
+        stepY -= sliderSpace;
 
         float y = fb_height - totalTabixY - sliderSpace; // + gap;  // start of tracks on canvas
         float t = (float) 0.005 * fb_width;
@@ -1801,7 +1811,6 @@ namespace Drawing {
 
         for (auto &rgn: regions) {
             bool any_text = true;
-            bool add_line = ((rgn.end - rgn.start) < opts.soft_clip_threshold);
             float xScaling = (stepX - gap2) / (float) (rgn.end - rgn.start);
             float padY = gap;
             int trackIdx = 0;
@@ -1812,7 +1821,8 @@ namespace Drawing {
             rgn.featureLevels.resize(tracks.size());
             for (auto &trk: tracks) {
 
-                SkPaint faceColour = trk.faceColour;
+                SkPaint &faceColour = trk.faceColour;
+                SkPaint &shadedFaceColour = trk.shadedFaceColour;
 
                 float right = ((float) (rgn.end - rgn.start) * xScaling) + padX;
                 canvas->save();
@@ -1867,12 +1877,12 @@ namespace Drawing {
                                              fonts, gap,
                                              f, any_text, rgn, rect, path, path2, padX, padY_track, stepX, step_track,
                                              y, h, h2, h4, gap2,
-                                             xScaling, nLevels, fLevelEnd, text, add_line, faceColour, pointSlop, strand);
+                                             xScaling, nLevels, fLevelEnd, text, faceColour, shadedFaceColour, pointSlop, strand, monitorScale);
 
                     } else {
                         drawTrackBlock(f.start, f.end, f.name, rgn, rect, path, padX, padY_track, y, h, stepX, stepY,
                                        gap, gap2,
-                                       xScaling, opts, canvas, fonts, any_text, true, add_line, false, fLevelEnd, f.vartype, monitorScale,
+                                       xScaling, opts, canvas, fonts, any_text, true, false, fLevelEnd, f.vartype, monitorScale,
                                        text, opts.sv_arcs, trk.kind == HGW::FType::ROI, faceColour, pointSlop, strand);
                     }
                 }
@@ -2009,7 +2019,8 @@ namespace Drawing {
                            const std::unordered_map<std::string, std::vector<Ideo::Band>> &ideogram,
                            SkCanvas *canvas,
                            const faidx_t *fai, float fb_width,
-                           float fb_height, float monitorScale, float plot_gap) {
+                           float fb_height, float monitorScale, float plot_gap, bool addLocation) {
+
         SkPaint paint, light_paint, line;
         paint.setARGB(255, 240, 32, 73);
 
@@ -2031,7 +2042,7 @@ namespace Drawing {
 
         const float top = fb_height - (yh * 2);
         const float colWidth = (float) fb_width / (float) regions.size();
-        const float gap = 25 * monitorScale;  // ideogram is smaller than the full page width, by this ammount
+        const float gap = 25 * monitorScale;  // ideogram is smaller than the full page width, by this amount
         const float gap2 = 50 * monitorScale;
         const float drawWidth = colWidth - gap2;
         const float scaleWidth = colWidth - plot_gap - plot_gap;
@@ -2051,33 +2062,37 @@ namespace Drawing {
             }
             float xp = (regionIdx * colWidth) + gap;
 
-            path.reset();
-            path.moveTo(xp, top + yh_two_thirds );
-            path.lineTo(xp + drawWidth, top + yh_two_thirds);
-            canvas->drawPath(path, line);
+            if (addLocation || !ideogram.empty()) {
+                path.reset();
+                path.moveTo(xp, top + yh_two_thirds );
+                path.lineTo(xp + drawWidth, top + yh_two_thirds);
+                canvas->drawPath(path, line);
 
-            auto it = ideogram.find(region.chrom);
-            if (it != ideogram.end()) {
-                const std::vector<Ideo::Band>& bands = it->second;
-                for (const auto& b : bands) {
-                    float sb = (float) b.start / (float)region.chromLen;
-                    float eb = (float) b.end / (float)region.chromLen;
-                    float wb = (eb - sb) * drawWidth;
-                    rect.setXYWH(xp + (sb * drawWidth),
-                                 top + yh_one_third,
-                                 wb,
-                                 yh_two_thirds);
-                    canvas->drawRect(rect, b.paint);
-                    if (wb > 2) {
-                        canvas->drawRect(rect, light_paint);
+                auto it = ideogram.find(region.chrom);
+                if (it != ideogram.end()) {
+                    const std::vector<Ideo::Band>& bands = it->second;
+                    for (const auto& b : bands) {
+                        float sb = (float) b.start / (float)region.chromLen;
+                        float eb = (float) b.end / (float)region.chromLen;
+                        float wb = (eb - sb) * drawWidth;
+                        rect.setXYWH(xp + (sb * drawWidth),
+                                     top + yh_one_third,
+                                     wb,
+                                     yh_two_thirds);
+                        canvas->drawRect(rect, b.paint);
+                        if (wb > 2) {
+                            canvas->drawRect(rect, light_paint);
+                        }
                     }
                 }
             }
-            rect.setXYWH(xp + (s * drawWidth),
-                         top,
-                         w,
-                         yh + yh_one_third);
-            canvas->drawRect(rect, paint);
+            if (addLocation) {
+                rect.setXYWH(xp + (s * drawWidth),
+                             top,
+                             w,
+                             yh + yh_one_third);
+                canvas->drawRect(rect, paint);
+            }
 
             // draw scale bar
             if (opts.scale_bar) {
