@@ -374,7 +374,8 @@ namespace HGW {
             return;
         }
         bool filter = !filters.empty();
-        const int parse_mods_threshold = (opts.parse_mods) ? 50 : 0;
+
+        const int parse_mods_threshold = (opts.parse_mods) ? opts.mods_qual_threshold : 0;
 
         int j = 0;
         while (sam_itr_next(b, iter_q, readQueue[j].delegate) >= 0) {
@@ -452,11 +453,10 @@ namespace HGW {
         iter_q = sam_itr_queryi(index, tid, region->start, region->end);
         if (iter_q == nullptr) {
             std::cerr << "\nError: Null iterator when trying to fetch from HTS file in collectReadsAndCoverage " << region->chrom << " " << region->start << " " << region->end << std::endl;
-//            throw std::runtime_error("");
             return;
         }
         bool filter = !filters.empty();
-        const int parse_mods_threshold = (opts.parse_mods) ? 50 : 0;
+        const int parse_mods_threshold = (opts.parse_mods) ? opts.mods_qual_threshold : 0;
 
         while (sam_itr_next(b, iter_q, readQueue.back().delegate) >= 0) {
             src = readQueue.back().delegate;
@@ -1227,6 +1227,14 @@ namespace HGW {
         }
     }
 
+    void GwTrack::setPaint(SkPaint &faceColour) {
+        this->faceColour = faceColour;
+        this->faceColour.setAntiAlias(true);
+        this->shadedFaceColour.setAntiAlias(true);
+        int c = faceColour.getColor();
+        this->shadedFaceColour.setARGB(faceColour.getAlpha() * 0.5, SkColorGetR(c), SkColorGetG(c), SkColorGetB(c));
+    }
+
     void GwTrack::open(const std::string &p, bool add_to_dict=true) {
         fileIndex = 0;
         path = p;
@@ -1432,9 +1440,7 @@ namespace HGW {
                 return;
             }
             int count = 0;
-            std::vector<Utils::TrackBlock> track_blocks;
-            ankerl::unordered_dense::map< std::string, int> name_to_track_block_idx;
-
+            ankerl::unordered_dense::map< std::string, std::vector<Utils::TrackBlock>> track_blocks;
             while (true) {
                 auto got_line = (bool)getline(*fpu, tp);
                 if (!got_line) {
@@ -1445,6 +1451,7 @@ namespace HGW {
                 if (tp[0] == '#') {
                     continue;
                 }
+
                 Utils::TrackBlock b;
                 b.parts = Utils::split(tp, '\t');
                 if (b.parts.size() < 9) {
@@ -1454,7 +1461,7 @@ namespace HGW {
                 b.line = tp;
                 b.chrom = b.parts[0];
                 b.vartype = b.parts[2];
-                b.start = std::stoi(b.parts[3]);
+                b.start = std::stoi(b.parts[3]) - 1;
                 b.end = std::stoi(b.parts[4]);
                 if (b.parts[6] == "+") {
                     b.strand = 1;
@@ -1463,29 +1470,60 @@ namespace HGW {
                 } else {
                     b.strand = 0;
                 }
+
                 for (const auto &item :  Utils::split(b.parts[8], ';')) {
                     if (kind == GFF3_NOI) {
                         std::vector<std::string> keyval = Utils::split(item, '=');
-                        if (keyval[0] == "ID") {
+                        if (keyval[0] == "Name" || keyval[0] == "gene_name") {
+                            b.name = keyval[1];
+                            if (!b.parent.empty()) {
+                                break;
+                            }
+                        }
+                        else if (b.name.empty() && keyval[0] == "ID") {
                             b.name = keyval[1];
                         }
                         else if (keyval[0] == "Parent") {
                             b.parent = keyval[1];
-                            break;
-                        }
-                    } else {
-                        std::vector<std::string> keyval = Utils::split(item, ' ');
-                        if (keyval[0] == "transcript_id") {
                             b.name = keyval[1];
                         }
-                        else if (keyval[0] == "gene_id") {
+                    } else {  // GTF_NOI
+                        std::vector<std::string> keyval = Utils::split(item, ' ');
+                        if (keyval[0] == "gene_id") {
                             b.parent = keyval[1];
+                            b.name = keyval[1];
+                        } else if (keyval[0] == "gene_name") {
+                            b.parent = keyval[1];
+                            b.name = keyval[1];
                             break;
+                        } else if (b.name.empty() && keyval[0] == "transcript_id") {
+                            b.name = keyval[1];
                         }
                     }
-
                 }
-                allBlocks[b.chrom].add(b.start, b.end, b);
+                if (b.name.empty()) {
+                    continue;
+                }
+                track_blocks[b.parent].push_back(std::move(b));
+
+            }
+            for (const auto& kv : track_blocks) {
+                int left = 1000000000;
+                int right = 0;
+                for (const auto &b : kv.second) {
+                    if (b.start < left) {
+                        left = b.start;
+                    }
+                    if (b.end > right) {
+                        right = b.end;
+                    }
+                }
+                if (left == 1000000000 || right == 0) {
+                    continue;
+                }
+                for (const auto &b : kv.second) {
+                    allBlocks[b.chrom].add(left, right, b);
+                }
             }
 
         } else if (kind == BED_IDX) {
@@ -1564,11 +1602,7 @@ namespace HGW {
             } else {
                 if (allBlocks.contains(rgn->chrom)) {
                     std::vector<size_t> a;
-                    if (kind == GFF3_NOI || kind == GTF_NOI) {
-                        allBlocks[rgn->chrom].overlap(std::max(1, rgn->start - 100000), rgn->end + 100000, a);
-                    } else {
-                        allBlocks[rgn->chrom].overlap(rgn->start, rgn->end, a);
-                    }
+                    allBlocks[rgn->chrom].overlap(rgn->start, rgn->end, a);
                     overlappingBlocks.clear();
                     if (a.empty()) {
                         done = true;
@@ -1640,6 +1674,7 @@ namespace HGW {
             return;
         }
         strand = 0;
+
         if (kind > BCF_IDX) {  // non indexed cached VCF_NOI / BED_NOI / GFF3 (todo) / GW_LABEL / STDIN?
             // add_to_dict==false, only BED and GW_LABEL files supported (iterate whole file)
             if (!add_to_dict) {
@@ -1806,7 +1841,7 @@ namespace HGW {
                 parts = Utils::split(str.s, '\t');
                 chrom = parts[0];
                 chrom2 = chrom;
-                start = std::stoi(parts[3]);
+                start = std::stoi(parts[3]) - 1;
                 stop = std::stoi(parts[4]);
                 if (parts[6] == "+") {
                     strand = 1;
@@ -1819,7 +1854,12 @@ namespace HGW {
                 for (const auto &item :  Utils::split(parts[8], ';')) {
                     if (kind == GFF3_IDX) {
                         std::vector<std::string> keyval = Utils::split(item, '=');
-                        if (keyval[0] == "ID") {
+                        if (keyval[0] == "Name") {
+                            parent = keyval[1];
+                            rid = keyval[1];
+                            break;
+                        }
+                        else if (keyval[0] == "ID") {
                             rid = keyval[1];
                         }
                         else if (keyval[0] == "Parent") {
@@ -1828,12 +1868,15 @@ namespace HGW {
                         }
                     } else {
                         std::vector<std::string> keyval = Utils::split(item, ' ');
-                        if (keyval[0] == "transcript_id") {
-                            rid = keyval[1];
-                        }
-                        else if (keyval[0] == "gene_id") {
+                        if (keyval[0] == "gene_name") {
                             parent = keyval[1];
+			                rid = keyval[1];
                             break;
+                        } else if (keyval[0] == "gene_id") {
+                            parent = keyval[1];
+                            rid = keyval[1];
+                        } else if (keyval[0] == "transcript_id") {
+                            rid = keyval[1];
                         }
                     }
                 }
@@ -2271,12 +2314,13 @@ namespace HGW {
                       { return a->start < b->start || (a->start == b->start && a->end < b->end);});
 
             track.anyToDraw = false;
-            bool restAreThin = false;
+            bool between_codons = false;
             for (auto &g: pg.second) {
                 if (j == 0) {
                     track.chrom = g->chrom;
                     track.start = g->start;
-                    track.name = pg.first;
+                    track.name = g->name;
+
                     if (track.name.front() == '"') {
                         track.name.erase(0, 1);
                     }
@@ -2287,11 +2331,12 @@ namespace HGW {
                     if (track.parent.front() == '"') {
                         track.parent.erase(0, 1);
                     }
-                    if (track.name.back() == '"') {
+                    if (track.parent.back() == '"') {
                         track.parent.erase(track.parent.size() - 1, 1);
                     }
                     track.end = g->end;
                     track.strand = g->strand;
+
                 } else if (g->end > track.end) {
                     track.end = g->end;
                 }
@@ -2300,21 +2345,19 @@ namespace HGW {
                 track.s.push_back(g->start);
                 track.e.push_back(g->end);
 
-                if (restAreThin) {
-                    track.drawThickness.push_back(1);
-                } else if (g->vartype == "exon" || g->vartype == "CDS") {
+                if (g->vartype == "CDS") { // g->vartype == "exon" ||
+                    track.anyToDraw = true;
                     track.drawThickness.push_back(2);  // fat line
-                    if (!track.anyToDraw) { track.anyToDraw = true; }
-                } else if (g->vartype == "mRNA" || g->vartype == "gene") {
+                } else if (g->vartype == "mRNA" || g->vartype == "gene" || g->vartype == "exon") {
                     track.drawThickness.push_back(0);  // no line
                 } else if (g->vartype == "start_codon") {
+                    between_codons = !between_codons;
                     track.coding_start = g->start;
-                    std::fill(track.drawThickness.begin(), track.drawThickness.end(), 1);
-                    track.drawThickness.push_back(2);
+                    track.drawThickness.push_back(0);
                 } else if (g->vartype == "stop_codon") {
+                    between_codons = !between_codons;
                     track.coding_end = g->end;
-                    restAreThin = true;
-                    track.drawThickness.push_back(2);
+                    track.drawThickness.push_back(0);
                 } else {
                     track.drawThickness.push_back(1);
                     if (!track.anyToDraw) { track.anyToDraw = true; }
