@@ -129,10 +129,10 @@ namespace Commands {
     }
 
     Err sam(Plot* p, std::string& command, std::vector<std::string>& parts, std::ostream& out) {
-        p->redraw = true;
         if (!p->selectedAlign.empty()) {
             if (command == "sam") {
                 Term::printSelectedSam(p->selectedAlign, out);
+                return Err::NONE;
             } else if (parts.size() == 3 && (Utils::endsWith(parts[2], ".sam") || Utils::endsWith(parts[2], ".bam") || Utils::endsWith(parts[2], ".cram"))) {
                 std::string o_str = parts[2];
                 if (p->headers.empty() || p->regionSelection >= (int)p->headers.size()) {
@@ -220,7 +220,6 @@ namespace Commands {
                 sam_close(h_out);
             }
         }
-        p->processed = true;
         return Err::NONE;
     }
 
@@ -669,6 +668,9 @@ namespace Commands {
         } else {
             return Err::OPTION_NOT_UNDERSTOOD;
         }
+        for (auto &t: p->tracks) {
+            t.setPaint(p->opts.theme.fcTrack);
+        }
         p->processed = false;
         return Err::NONE;
     }
@@ -1342,6 +1344,7 @@ namespace Commands {
         else if (c == "lcJoins") { e = Themes::GwPaint::lcJoins; }
         else if (c == "lcCoverage") { e = Themes::GwPaint::lcCoverage; }
         else if (c == "lcLightJoins") { e = Themes::GwPaint::lcLightJoins; }
+        else if (c == "lcGTFJoins") { e = Themes::GwPaint::lcGTFJoins; }
         else if (c == "lcLabel") { e = Themes::GwPaint::lcLabel; }
         else if (c == "lcBright") { e = Themes::GwPaint::lcBright; }
         else if (c == "tcDel") { e = Themes::GwPaint::tcDel; }
@@ -1387,7 +1390,10 @@ namespace Commands {
                 out << termcolor::red << "Error:" << termcolor::reset << " track index out of range\n";
                 return Err::SILENT;
             }
-            p->tracks[ind].faceColour.setARGB(alpha, red, green, blue);
+            SkPaint new_paint;
+            new_paint.setARGB(alpha, red, green, blue);
+            p->tracks[ind].setPaint(new_paint);
+//            p->tracks[ind].faceColour.setARGB(alpha, red, green, blue);
             refreshGw(p);
             return Err::NONE;
         }
@@ -1520,6 +1526,9 @@ namespace Commands {
 
     void cache_command_or_handle_err(Plot* p, Err result, std::ostream& out,
                                     std::vector<std::string>* applied, std::string& command) {
+        if (result != NONE) {
+            p->redraw = false;
+        }
         switch (result) {
             case NONE:
                 applied->push_back(command);
@@ -1569,14 +1578,6 @@ namespace Commands {
                 out << termcolor::red << "Error:" << termcolor::reset << " Input could not be parsed\n";
                 return;
         }
-        return;
-//        p->redraw = true;
-//        if (p->mode == Manager::Show::SINGLE) {
-//            for (auto &cl : p->collections) {
-//                cl.skipDrawingReads = true;
-//                cl.skipDrawingCoverage = true;
-//            }
-//        }
     }
 
     // Command functions capture these parameters only
