@@ -572,32 +572,22 @@ namespace Segs {
 #endif
                     return -1;
                 }
+//                Old code here:
+//                for (cp = state->MMend[i]-1; cp != state->MM[i]; cp--)
+//                    if (*cp == ',')
+//                        break;
 
-//                if (i == 0) {
-//                    cp = state->MM[i];
-//                } else {
-
-                    if (i > 0) {
-                        char *cp_begin = state->MMend[0];
-                        char *cp2 = state->MMend[i];
-                        cp = state->MMend[i]-1;
-                        while (cp != cp_begin && (cp == cp2 || *cp != ',')) {
-                            --cp;
-                            --cp2;
-                        }
-                    } else {
-                        return -1;
+                if (i >= 0) {
+                    char *cp_begin = state->MMend[0];
+                    char *cp2 = state->MMend[i];
+                    cp = state->MMend[i]-1;
+                    while (cp != cp_begin && (cp == cp2 || *cp != ',')) {
+                        --cp;
+                        --cp2;
                     }
-
-
-//                    for (cp = state->MMend[i]-1; cp != state->MM[i]; cp--) {
-//                        std::cout << (cp == nullptr) << " " <<  i << "  5a2.\n";
-//                        if (i < 1 || *cp == ',') {
-//                            break;
-//                        }
-//                        std::cout << "  5a2.\n";
-//                    }
-//                }
+                } else {
+                    return -1;
+                }
 
                 state->MMend[i] = cp;
                 if (cp != state->MM[i])
@@ -695,6 +685,8 @@ namespace Segs {
         }
 
         int r = bam_mods_at_next_pos(b, state, mods, n_mods);
+//        if (b->core.flag & 16)
+//            std::cout << (b->core.flag & 16) << " -- " << r << std::endl;
         return r > 0 ? r : 0;
     }
 
@@ -791,7 +783,7 @@ namespace Segs {
             self->haplotag = (HP_tag != nullptr) ? (int) bam_aux2i(HP_tag) : 0;
         }
 
-        if (parse_mods_threshold >= 0) {
+        if (parse_mods_threshold > 0) {
             hts_base_mod_state* mod_state = new hts_base_mod_state;
             int res = bam_parse_basemod_gw(src, mod_state, 0);
             if (res >= 0) {
@@ -817,10 +809,8 @@ namespace Segs {
 
             }
             delete mod_state;
-
         }
 
-
         self->y = -1;  // -1 has no level, -2 means initialized but filtered
         if (self->blocks.empty()) {
             self->y = -2;
